import os
from csv import DictReader

dir_path = os.path.dirname(os.path.realpath(__file__))
db_path = os.path.join(dir_path, 'db', 'cae2scian.tsv')
db = dict(
  [
    (r['cae_id'], dict(r)) for r in DictReader(open(db_path), delimiter='\t')
  ]
)

def cae(industry_code):
  return db[industry_code]



try:
  from setuptools import setup
except ImportError:
  from distutils.core import setup

config = {
  'install_requires' : [],
  'description': 'Industry codes standard translator (CAE and SCIAN)',
  'version': '0.2.1',
  'packages': ['cae2scian'],
  'package_data': dict(cae2scian=['db/cae2scian.tsv']),
  'include_package_data': True,
  'name': 'cae2scian'
}

setup(**config)
